==> jc-1.4.0.tar.gz: soot/jimple/parser/node/AUnopExpression.h <==
// public final class soot.jimple.parser.node.AUnopExpression

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 14a2f354eb2123d8 soot_jimple_parser_node_AUnopExpression
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class 17bf07e10ea3d87a soot_jimple_parser_node_PExpression

// header file dependencies
// @dep_header soot_jimple_parser_node_PExpression

#include "soot/jimple/parser/node/PExpression.h"

#ifndef _JC_soot_jimple_parser_node_AUnopExpression_H_
#define _JC_soot_jimple_parser_node_AUnopExpression_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_PUnopExpr$object;
struct _jc_soot_jimple_parser_node_Switch$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_AUnopExpression$sub_refs	_jc_soot_jimple_parser_node_AUnopExpression$sub_refs;
typedef struct _jc_soot_jimple_parser_node_AUnopExpression$sub_nonrefs	_jc_soot_jimple_parser_node_AUnopExpression$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_AUnopExpression$refs	_jc_soot_jimple_parser_node_AUnopExpression$refs;
typedef struct _jc_soot_jimple_parser_node_AUnopExpression$nonrefs	_jc_soot_jimple_parser_node_AUnopExpression$nonrefs;
typedef struct _jc_soot_jimple_parser_node_AUnopExpression$object	_jc_soot_jimple_parser_node_AUnopExpression$object;

typedef const struct _jc_soot_jimple_parser_node_AUnopExpression$vmethods	_jc_soot_jimple_parser_node_AUnopExpression$vmethods;
typedef const struct _jc_soot_jimple_parser_node_AUnopExpression$vtable	_jc_soot_jimple_parser_node_AUnopExpression$vtable;
typedef const struct _jc_soot_jimple_parser_node_AUnopExpression$vtype	_jc_soot_jimple_parser_node_AUnopExpression$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_AUnopExpression$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_AUnopExpression$object *);
extern void _jc_soot_jimple_parser_node_AUnopExpression$method$_init$0540b7e3d374e027(_jc_env *, struct _jc_soot_jimple_parser_node_AUnopExpression$object *, struct _jc_soot_jimple_parser_node_PUnopExpr$object *);

// Virtual methods
extern void _jc_soot_jimple_parser_node_AUnopExpression$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_AUnopExpression$object *, struct _jc_object *);
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_AUnopExpression$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_AUnopExpression$object *);
extern struct _jc_soot_jimple_parser_node_PUnopExpr$object *_jc_soot_jimple_parser_node_AUnopExpression$method$getUnopExpr$e9405a76a5dee870(_jc_env *, struct _jc_soot_jimple_parser_node_AUnopExpression$object *);
extern void _jc_soot_jimple_parser_node_AUnopExpression$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_AUnopExpression$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_AUnopExpression$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_AUnopExpression$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_AUnopExpression$method$setUnopExpr$808762c0a5b69191(_jc_env *, struct _jc_soot_jimple_parser_node_AUnopExpression$object *, struct _jc_soot_jimple_parser_node_PUnopExpr$object *);
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_AUnopExpression$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_AUnopExpression$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_AUnopExpression$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_AUnopExpression$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_AUnopExpression$method_info$getUnopExpr$e9405a76a5dee870;
extern _jc_method _jc_soot_jimple_parser_node_AUnopExpression$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_AUnopExpression$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_AUnopExpression$method_info$setUnopExpr$808762c0a5b69191;
extern _jc_method _jc_soot_jimple_parser_node_AUnopExpression$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_AUnopExpression$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_AUnopExpression$object *, struct _jc_object *);
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_AUnopExpression$object *);
	struct _jc_soot_jimple_parser_node_PUnopExpr$object	*(*getUnopExpr$e9405a76a5dee870)(_jc_env *, struct _jc_soot_jimple_parser_node_AUnopExpression$object *);
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_AUnopExpression$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_AUnopExpression$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*setUnopExpr$808762c0a5b69191)(_jc_env *, struct _jc_soot_jimple_parser_node_AUnopExpression$object *, struct _jc_soot_jimple_parser_node_PUnopExpr$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_AUnopExpression$object *);
};

// Vtable
struct _jc_soot_jimple_parser_node_AUnopExpression$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PExpression$vmethods	soot_jimple_parser_node_PExpression;
	_jc_soot_jimple_parser_node_AUnopExpression$vmethods	soot_jimple_parser_node_AUnopExpression;
};

// Vtype
struct _jc_soot_jimple_parser_node_AUnopExpression$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_AUnopExpression$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AUnopExpression$sub_refs {
	struct _jc_soot_jimple_parser_node_PUnopExpr$object	*__5funopExpr__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_AUnopExpression$refs {
    _jc_soot_jimple_parser_node_AUnopExpression$sub_refs	soot_jimple_parser_node_AUnopExpression;
    _jc_soot_jimple_parser_node_PExpression$sub_refs	soot_jimple_parser_node_PExpression;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AUnopExpression$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_AUnopExpression$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PExpression$sub_nonrefs	soot_jimple_parser_node_PExpression;
    _jc_soot_jimple_parser_node_AUnopExpression$sub_nonrefs	soot_jimple_parser_node_AUnopExpression;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_AUnopExpression$object {
	_jc_soot_jimple_parser_node_AUnopExpression$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_AUnopExpression$vtype	*vtype;
	_jc_soot_jimple_parser_node_AUnopExpression$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_AUnopExpression$vtype _jc_soot_jimple_parser_node_AUnopExpression$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_AUnopExpression, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_AUnopExpression$class_object;

#endif	/* _JC_soot_jimple_parser_node_AUnopExpression_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/parser/node/AUnopExpression.h <==
// public final class soot.jimple.parser.node.AUnopExpression

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 14a2f354eb2123d8 soot_jimple_parser_node_AUnopExpression
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class 17bf07e10ea3d87a soot_jimple_parser_node_PExpression

// header file dependencies
// @dep_header soot_jimple_parser_node_PExpression

#include "soot/jimple/parser/node/PExpression.h"

#ifndef _JC_soot_jimple_parser_node_AUnopExpression_H_
#define _JC_soot_jimple_parser_node_AUnopExpression_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_PUnopExpr$object;
struct _jc_soot_jimple_parser_node_Switch$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_AUnopExpression$sub_refs	_jc_soot_jimple_parser_node_AUnopExpression$sub_refs;
typedef struct _jc_soot_jimple_parser_node_AUnopExpression$sub_nonrefs	_jc_soot_jimple_parser_node_AUnopExpression$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_AUnopExpression$refs	_jc_soot_jimple_parser_node_AUnopExpression$refs;
typedef struct _jc_soot_jimple_parser_node_AUnopExpression$nonrefs	_jc_soot_jimple_parser_node_AUnopExpression$nonrefs;
typedef struct _jc_soot_jimple_parser_node_AUnopExpression$object	_jc_soot_jimple_parser_node_AUnopExpression$object;

typedef const struct _jc_soot_jimple_parser_node_AUnopExpression$vmethods	_jc_soot_jimple_parser_node_AUnopExpression$vmethods;
typedef const struct _jc_soot_jimple_parser_node_AUnopExpression$vtable	_jc_soot_jimple_parser_node_AUnopExpression$vtable;
typedef const struct _jc_soot_jimple_parser_node_AUnopExpression$vtype	_jc_soot_jimple_parser_node_AUnopExpression$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_AUnopExpression$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_AUnopExpression$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AUnopExpression$method$_init$0540b7e3d374e027(_jc_env *, struct _jc_soot_jimple_parser_node_AUnopExpression$object *, struct _jc_soot_jimple_parser_node_PUnopExpr$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_parser_node_AUnopExpression$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_AUnopExpression$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_AUnopExpression$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_AUnopExpression$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_jimple_parser_node_PUnopExpr$object *_jc_soot_jimple_parser_node_AUnopExpression$method$getUnopExpr$e9405a76a5dee870(_jc_env *, struct _jc_soot_jimple_parser_node_AUnopExpression$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AUnopExpression$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_AUnopExpression$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AUnopExpression$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_AUnopExpression$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AUnopExpression$method$setUnopExpr$808762c0a5b69191(_jc_env *, struct _jc_soot_jimple_parser_node_AUnopExpression$object *, struct _jc_soot_jimple_parser_node_PUnopExpr$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_AUnopExpression$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_AUnopExpression$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_AUnopExpression$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_AUnopExpression$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_AUnopExpression$method_info$getUnopExpr$e9405a76a5dee870;
extern _jc_method _jc_soot_jimple_parser_node_AUnopExpression$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_AUnopExpression$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_AUnopExpression$method_info$setUnopExpr$808762c0a5b69191;
extern _jc_method _jc_soot_jimple_parser_node_AUnopExpression$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_AUnopExpression$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_AUnopExpression$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_AUnopExpression$object *) _JC_JCNI_ATTR;
	struct _jc_soot_jimple_parser_node_PUnopExpr$object	*(*getUnopExpr$e9405a76a5dee870)(_jc_env *, struct _jc_soot_jimple_parser_node_AUnopExpression$object *) _JC_JCNI_ATTR;
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_AUnopExpression$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_AUnopExpression$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*setUnopExpr$808762c0a5b69191)(_jc_env *, struct _jc_soot_jimple_parser_node_AUnopExpression$object *, struct _jc_soot_jimple_parser_node_PUnopExpr$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_AUnopExpression$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_parser_node_AUnopExpression$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PExpression$vmethods	soot_jimple_parser_node_PExpression;
	_jc_soot_jimple_parser_node_AUnopExpression$vmethods	soot_jimple_parser_node_AUnopExpression;
};

// Vtype
struct _jc_soot_jimple_parser_node_AUnopExpression$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_AUnopExpression$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AUnopExpression$sub_refs {
	struct _jc_soot_jimple_parser_node_PUnopExpr$object	*__5funopExpr__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_AUnopExpression$refs {
    _jc_soot_jimple_parser_node_AUnopExpression$sub_refs	soot_jimple_parser_node_AUnopExpression;
    _jc_soot_jimple_parser_node_PExpression$sub_refs	soot_jimple_parser_node_PExpression;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AUnopExpression$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_AUnopExpression$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PExpression$sub_nonrefs	soot_jimple_parser_node_PExpression;
    _jc_soot_jimple_parser_node_AUnopExpression$sub_nonrefs	soot_jimple_parser_node_AUnopExpression;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_AUnopExpression$object {
	_jc_soot_jimple_parser_node_AUnopExpression$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_AUnopExpression$vtype	*vtype;
	_jc_soot_jimple_parser_node_AUnopExpression$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_AUnopExpression$vtype _jc_soot_jimple_parser_node_AUnopExpression$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_AUnopExpression, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_AUnopExpression$class_object;

#endif	/* _JC_soot_jimple_parser_node_AUnopExpression_H_ */
